#
# spec file for package geekodoc
#
# Copyright (c) 2016-2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without  tests
#
Name:           geekodoc
Version:        2.3.1.1
Release:        15.2
Summary:        DocBook based RNG Schema for SUSE Documentation
License:        GPL-3.0-only
Group:          Productivity/Publishing/DocBook
URL:            https://github.com/openSUSE/geekodoc/archive/%{name}-%{version}.tar.gz
Source:         %{name}-%{version}.tar.bz2
# Taken from maintenance/novdoc-2019-02-01
# Created with:
# $ git archive --prefix=novdoc-20190201/ \
#               --output=/tmp/novdoc-20190201.tar.bz2 \
#               --format=tar HEAD novdoc/ catalog.d/
Source10:       novdoc-20190201.tar.bz2
BuildRequires:  docbook_5 >= 5.2
BuildRequires:  fdupes
BuildRequires:  jing
BuildRequires:  libxml2-tools
BuildRequires:  make
%if 0%{?is_opensuse}
BuildRequires:  openSUSE-release
%else
BuildRequires:  sles-release
%endif
BuildRequires:  python3-importlib_metadata
BuildRequires:  python3-rnginline
BuildRequires:  python3-setuptools
BuildRequires:  trang

Requires:       sgml-skel >= 0.7
Requires(post): sgml-skel >= 0.7
Requires(postun):sgml-skel >= 0.7
Conflicts:      suse-xsl-stylesheets < 2.0.6
BuildArch:      noarch

%description
GeekoDoc is a RELAX NG schema used for current SUSE documentation.

%package -n novdoc
Version:        1.0_%{version}
Release:        15.2
Summary:        DocBook based Schema for older SUSE Documentation
Group:          Productivity/Publishing/DocBook
Conflicts:      suse-xsl-stylesheets < 2.0.6

%description -n novdoc
NovDoc is a DTD/RELAX NG schema used for older SUSE documentation.

%prep
%autosetup
tar -xf %{SOURCE10}
mv novdoc-20190201/novdoc .
mv novdoc-20190201/catalog.d/novdoc.xml catalog.d/

%build
touch geekodoc/rng/geekodoc5.rnc
# GeekoDoc
./build.sh -vv

# Novdoc
%make_build -C novdoc/rng

%install
docbookxi_rnc="$(xmlcatalog /etc/xml/catalog http://www.docbook.org/xml/5.2/rng/docbookxi.rnc)"
docbookxi_rng="$(xmlcatalog /etc/xml/catalog http://www.docbook.org/xml/5.2/rng/docbookxi.rng)"

install -d %{buildroot}%{_datadir}/xml/{geekodoc/rng/{1_5.1,2_5.2},novdoc/rng} \
           %{buildroot}%{_sysconfdir}/xml/catalog.d

# Fix include for "lonely" schema:
sed -i "s#include \"docbookxi.rnc\"#include \"$docbookxi_rnc\"#" \
    build/geekodoc/rng/1_5.1/geekodoc-v1.rnc
sed -i "s#<include href=\"docbookxi.rng\">#<include href=\"$docbookxi_rng\">#" \
    build/geekodoc/rng/1_5.1/geekodoc-v1.rng

#### Install flat GeekoDoc:
cp -a  build/geekodoc/rng/ %{buildroot}%{_datadir}/xml/geekodoc/

pushd %{buildroot}%{_datadir}/xml/geekodoc/rng
# For compatibility reasons:
ln -s 1_5.1/geekodoc-v1-flat.rnc geekodoc5-flat.rnc
ln -s 1_5.1/geekodoc-v1-flat.rng geekodoc5-flat.rng
  pushd 1_5.1/
    ln -s geekodoc-v1-flat.rnc geekodoc5-flat.rnc
    ln -s geekodoc-v1-flat.rng geekodoc5-flat.rng
  popd
popd

#### Install Novdoc:
cp -a novdoc/dtd %{buildroot}%{_datadir}/xml/novdoc
cp novdoc/rng/novdocxi-flat.rn? novdoc/rng/novell.ent %{buildroot}%{_datadir}/xml/novdoc/rng

#### Install catalogs:
cp catalog.d/* %{buildroot}%{_sysconfdir}/xml/catalog.d/

# Fixup catalog paths
sed -i 's#"\.\./#"%{_datadir}/xml/#' %{buildroot}%{_sysconfdir}/xml/catalog.d/*

# Deal with duplicates
%fdupes  %{buildroot}%{_datadir}/xml/

%post
update-xml-catalog

%postun
update-xml-catalog

%post -n novdoc
update-xml-catalog

if [ ! -f %{_sysconfdir}/xml/suse-catalog.xml -a -x %{_bindir}/edit-xml-catalog ] ; then
    # susexsl entry
    edit-xml-catalog --group --catalog %{_sysconfdir}/xml/suse-catalog.xml \
       --del suse_schemas
    edit-xml-catalog --group --catalog %{_sysconfdir}/xml/suse-catalog.xml \
       --del novdoc-1.0
fi
exit 0

%postun -n novdoc
update-xml-catalog

%if 0%{with tests}
%check
./tests/run-tests.sh -V xmllint
./tests/run-tests.sh -V jing

echo "### Checking catalog entries..."
for uri in \
   urn:x-suse:rnc:v1:geekodoc-flat \
   urn:x-suse:rng:v1:geekodoc-flat \
   urn:x-suse:rnc:v2:geekodoc-flat \
   urn:x-suse:rng:v2:geekodoc-flat \
   urn:x-suse:rng:geekodoc5-flat.rng \
   urn:x-suse:rng:geekodoc5-flat.rnc \
   https://github.com/openSUSE/geekodoc/raw/master/geekodoc/rng/geekodoc5-flat.rnc \
   https://github.com/openSUSE/geekodoc/raw/master/geekodoc/rng/geekodoc5-flat.rng \
   ;
  do
  xmlcatalog %{buildroot}%{_sysconfdir}/xml/catalog.d/geekodoc.xml $uri || exit $?
done
%endif

%files
%license LICENSE ChangeLog
%config %{_sysconfdir}/xml/catalog.d/geekodoc*.xml
%dir %{_datadir}/xml/geekodoc
%{_datadir}/xml/geekodoc/*
# These files are just build artifacts that need to be excluded:
%exclude %{_datadir}/xml/geekodoc/rng/*/docbook*
%exclude %{_datadir}/xml/geekodoc/rng/*/db*
%exclude %{_datadir}/xml/geekodoc/rng/*/its*
%exclude %{_datadir}/xml/geekodoc/rng/*/trans*
%exclude %{_datadir}/xml/geekodoc/rng/*/xinclude*
%exclude %{_datadir}/xml/geekodoc/rng/*/*.rni
%exclude %{_datadir}/xml/geekodoc/rng/*/geekodoc-v[12].rn[cg]
%exclude %{_datadir}/xml/geekodoc/rng/*/geekodoc5.rnc

%files -n novdoc
%license LICENSE
%config %{_sysconfdir}/xml/catalog.d/novdoc.xml
%dir %{_datadir}/xml/novdoc
%{_datadir}/xml/novdoc/*

%changelog
* Fri Jul 26 2024 Thomas Schraitle <thomas.schraitle@suse.com> - 2.3.1.1
- Bump version to 2.3.1.1
  No substantial changes, just a new patch release to get the daps-toolchain
  container triggered
* Tue Jan  9 2024 Thomas Schraitle <thomas.schraitle@suse.com> - 2.3.1
- Release 2.3.1
  Add test case for width with em unit
  Regenerate archive
* Sat Dec  2 2023 Thomas Schraitle <thomas.schraitle@suse.com> - 2.3.0
- Release 2.3.0
  - Disable unnecessary DocBook 5.2 elements (#116, #110)
  - Add para between list title and following list element (#117, #105)
  - Remove entityref from {audio,image,text,video}data (#117)
  - Validate with attribute (float + unit) (#119, #103)
* Thu Jun 15 2023 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire python3-importlib_metadata: mandatory when building
  using python 3.11+.
* Wed Feb 15 2023 Thomas Schraitle <thomas.schraitle@suse.com> - 2.2.2
- Release 2.2.2
  Fix #114: Create additional links
  * Create geekodoc-latest-flat.rn{c,g}
  * Add catalog entries to point to latest URIs
* Wed Feb 15 2023 Thomas Schraitle <thomas.schraitle@suse.com> - 2.2.1
- Release 2.2.1
  - Introduce "latest" link (#114)
* Thu Feb  9 2023 Thomas Schraitle <thomas.schraitle@suse.com> - 2.2.0
- Release 2.2.0
  - Base GeekoDoc2 on DocBook 5.2CR5
  - Correct GeekoDoc1 with transclusion attributes. The transclusion.rnc
    file is reduced to the bare minimum as those attributes are
    provided by DocBook 5.2CR5 already.
* Thu Apr 21 2022 Thomas Schraitle <thomas.schraitle@suse.com> - 2.1.1
- Release 2.1.1
  Revert format removal in imagedata (#102)
* Wed Apr 13 2022 Thomas Schraitle <thomas.schraitle@suse.com> - 2.1.0
- Release 2.1.0
  - Fix #80: disallow xml:id on listitems (#82)
  - Feature/prompt role in #94
  - Fix #90: Restrict char set of prof attributes (#92)
  - rm @format from mediaobject (#93)
  - Allow videoobject and videodata (#101)
* Fri Sep  3 2021 Thomas Schraitle <thomas.schraitle@suse.com> - 2.0.0
- Release 2.0.0, no substantial changes
* Fri Aug  6 2021 Thomas Schraitle <thomas.schraitle@suse.com> - 2.0.0.beta4
- Prepare 2.0.0 beta4
  - Introduce external directory in source dir
  - Update ChangeLog
  - Add test cases for both GeekoDoc versions
  - Catalog changes
    Remove old non-flat URIs as this was not really needed
    Keep URIs with flat
  - Introduce new directory structure under /usr/share/xml/geekodoc/rng/
  - Add new catalog URIs:
  - urn:x-suse:rnc:v1:geekodoc-flat
  - urn:x-suse:rnc:v2:geekodoc-flat
  - urn:x-suse:rng:v1:geekodoc-flat
  - urn:x-suse:rng:v2:geekodoc-flat
  - The old URIs are still available:
  - https://github.com/openSUSE/geekodoc/raw/master/geekodoc/rng/v1/geekodoc5-flat.rng
  - https://github.com/openSUSE/geekodoc/raw/master/geekodoc/rng/v1/geekodoc5-flat.rnc
  - urn:x-suse:rng:geekodoc5-flat.rng
- GeekoDoc v2:
  - Base it on DocBook 5.2b10a5 (dbitsxi)
  - Identify GeekoDoc as "5.2-subset GeekoDoc-2"
  - Incorporate all the changes from GeekoDoc v1
  - Fix #73: Restrict xml:id/linkend to alphanum + "-" (#75)
  - Release GeekoDoc 2.0.0 (#76)
  - Use dbits.rnc as a basis, instead of docbookxi.rnc for GeekoDoc v1.
    This is needed for translation purposes.
- GeekoDoc v1:
  - Describe installation on Debian/Ubuntu (#85)
  - Fix #69: reduce content model of replaceable (#71)
  - Fix #64: disallow empty sections (#72)
  - Fix #59: Reduce content model of command (#66)
  - Fix #63: restrict content model of book
  - Fix #61: remove depth attribute on imagedata
* Wed Oct 14 2020 Thomas Schraitle <thomas.schraitle@suse.com> - 2.0.0.beta1
- Prepare 2.0.0 beta1 (WIP)
- Base GeekoDoc v2 on dbits
- From version 2, only the flat file is packaged as the normal one
  is not really used.
- See ChangeLog for further details
* Fri Feb  9 2018 thomas.schraitle@suse.com
- Bugfix release 1.0.2.1
  https://github.com/openSUSE/geekodoc/releases/tag/v1.0.2.1
  * Correct version in GeekoDoc schema
  * Add missing 'fig' value (#43)
  * Improve test suite
* Wed Feb  7 2018 thomas.schraitle@suse.com
- Add bcond_with tests to activate test suite
* Tue Feb  6 2018 thomas.schraitle@suse.com
- Release 1.0.2
  https://github.com/openSUSE/geekodoc/releases/tag/v1.0.2
  Only a package release without any changes in the schemas.
  Fixes issue #41 to reduce number of files in packages
* Tue Feb  6 2018 thomas.schraitle@suse.com
- Remove number of files in package; fixes openSUSE/geekodoc#41
  some files are only useful for development
* Tue Jan 30 2018 thomas.schraitle@suse.com
  Release 1.0.1
  https://github.com/openSUSE/geekodoc/releases/tag/v1.0.1
  * Geekodoc
  * Forbid xml:id on row and entry (#37)
  * Allow affiliation inside author (#36)
  * Forbid xml:id on remark (#32)
  * Inconsistency between informalfigure and informaltable (#35)
  * Allow sections (#34)
  * Novdoc
  no changes
* Thu Oct 26 2017 thomas.schraitle@suse.com
  Release 1.0.0
  https://github.com/openSUSE/geekodoc/releases/tag/v1.0.0
  * Geekodoc
  * Missing mediaobject in cover (#30)
  * Novdoc
  no changes
* Fri Oct 13 2017 thomas.schraitle@suse.com
  Release 0.9.9
  https://github.com/openSUSE/geekodoc/releases/tag/v0.9.9
  * Geekodoc
  * Allow lowercase Values in format attribute (#29)
  * Add list elements in taskprerequisites (#25)
  * Novdoc
  * No changes
* Fri Sep 15 2017 thomas.schraitle@suse.com
  Release 0.9.8
  https://github.com/openSUSE/geekodoc/releases/tag/v0.9.8
  Release 0.9.8
  * GeekoDoc
  * Restrict Possible Values in format Attribute (#24)
  * Fix outdated Schematron rules (#22)
  * Implement task elements (#20)
  * Adapt content model of task* elements (#1)
  * Add test cases and use Travis to check schema
  * Spec file:
  * Correct summary
* Thu Jun  1 2017 sknorr@suse.com
- Make sure that we ship the LICENSE file in the package
* Thu Dec  1 2016 toms@opensuse.org
  Release 0.9.7
  https://github.com/openSUSE/geekodoc/releases/tag/v0.9.7
  Release 0.9.7
  * GeekoDoc
  * link without "xlink:href" attribute is currently valid (#15)
  * Novdoc
  * Content model of step is not determinist (#17)
* Thu Nov 24 2016 toms@opensuse.org
  Release 0.9.6
  https://github.com/openSUSE/geekodoc/releases/tag/v0.9.6
  * GeekoDoc
  * Remove title in step (#4)
  * Empty <xref/> does not trigger a warning (#9)
  * Allow common attributes in link (#10)
  * Disallow xreflabel (#11)
  * Restrict <results> element (#14)
  * Novdoc
  * Missing novdocx-core.rnc (#5)
  * Allow <mediaobject> only in <figure> and
  * <informalfigure> (#7)
  * Fix content model for step to allow para, substeps,
  * para (#12)
  * Allow phrase inside productnumber (#13)
  * Both
  * Update Novdoc/GeekoDoc to disallow screen in entry (#2)
  * Spec file changes:
  * Generate Novdoc RNC/RNG files to add missing files
* Fri Sep 16 2016 sknorr@suse.com
- Added missing build dependency on trang
* Fri Aug 19 2016 fvogt@suse.com
- Initial package
